"""RIOT generator is a helper library for bootstraping RIOT code.

It can be used to bootstrap:
- a new board support
- a new external application
- a new RIOT example application
- a new test application
- a new package for RIOT
"""

__version__ = '0.3.0'

from .generator import cli  # noqa
